==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/analysis/ActiveUseTagger.h <==
// public class org.dellroad.jc.cgen.analysis.ActiveUseTagger

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ae0888c6d5ee6b71 org_dellroad_jc_cgen_analysis_ActiveUseTagger

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_ActiveUseTagger_H_
#define _JC_org_dellroad_jc_cgen_analysis_ActiveUseTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object;
struct _jc_soot_Body$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vmethods	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtable	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtype	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_soot_Body$object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *);

// Virtual methods
extern struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$getAnalysis$5a0e473a4bfb4d82(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$tag$26583c43862cd8e3(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_soot_Body$object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$tagField$532f1b25302ac399(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$tagInvoke$c5651612e98f5a77(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method_info$getAnalysis$5a0e473a4bfb4d82;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method_info$tag$26583c43862cd8e3;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method_info$tagField$532f1b25302ac399;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method_info$tagInvoke$c5651612e98f5a77;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vmethods {
	struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object	*(*getAnalysis$5a0e473a4bfb4d82)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *);
	void	(*tag$26583c43862cd8e3)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_soot_Body$object *);
	void	(*tagField$532f1b25302ac399)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_object *, struct _jc_object *);
	void	(*tagInvoke$c5651612e98f5a77)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vmethods	org_dellroad_jc_cgen_analysis_ActiveUseTagger;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_refs {
	struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object	*analysis;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$refs {
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_refs	org_dellroad_jc_cgen_analysis_ActiveUseTagger;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_nonrefs	org_dellroad_jc_cgen_analysis_ActiveUseTagger;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object {
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtype _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_ActiveUseTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_ActiveUseTagger_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/analysis/ActiveUseTagger.h <==
// public class org.dellroad.jc.cgen.analysis.ActiveUseTagger

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ae0888c6d5ee6b71 org_dellroad_jc_cgen_analysis_ActiveUseTagger

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_analysis_ActiveUseTagger_H_
#define _JC_org_dellroad_jc_cgen_analysis_ActiveUseTagger_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object;
struct _jc_soot_Body$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_jimple_Stmt$object;
struct _jc_soot_toolkits_graph_UnitGraph$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$refs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$refs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$nonrefs	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object;

typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vmethods	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtable	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtype	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$_init$4a1d314cee6c2507(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_soot_toolkits_graph_UnitGraph$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object *_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$getAnalysis$5a0e473a4bfb4d82(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$tag$26583c43862cd8e3(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$tagField$532f1b25302ac399(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method$tagInvoke$c5651612e98f5a77(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method_info$getAnalysis$5a0e473a4bfb4d82;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method_info$tag$26583c43862cd8e3;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method_info$tagField$532f1b25302ac399;
extern _jc_method _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$method_info$tagInvoke$c5651612e98f5a77;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vmethods {
	struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object	*(*getAnalysis$5a0e473a4bfb4d82)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *) _JC_JCNI_ATTR;
	void	(*tag$26583c43862cd8e3)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
	void	(*tagField$532f1b25302ac399)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*tagInvoke$c5651612e98f5a77)(_jc_env *, struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vmethods	org_dellroad_jc_cgen_analysis_ActiveUseTagger;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_refs {
	struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseAnalysis$object	*analysis;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$refs {
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_refs	org_dellroad_jc_cgen_analysis_ActiveUseTagger;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$sub_nonrefs	org_dellroad_jc_cgen_analysis_ActiveUseTagger;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$object {
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$vtype _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_analysis_ActiveUseTagger, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_analysis_ActiveUseTagger$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_analysis_ActiveUseTagger_H_ */
